@@ -73,6 +73,9 @@ use std::{
     cell::UnsafeCell,
 };
 
+/// A type alias for [`Fuse<T>`].
+pub type Fuze<T> = Fuse<T>;
+
 struct OneTime<T> {
     pub has_value: AtomicBool,
     pub cell: UnsafeCell<MaybeUninit<T>>,
@@ -137,6 +140,9 @@ pub struct Fuse<T> {
 }
 
 unsafe impl<T> Send for Fuse<T> { }
+// SAFETY: lighting a `Fuse` is consuming and requires ownership, which
+// ensures that there is only one instance modifying the internal state.
+unsafe impl<T> Sync for Fuse<T> { }
 
 /// Result of a bomb explosion.
 /// 
@@ -201,6 +207,16 @@ impl<T> Fuse<T> {
         }
     }
 
+    /// Ignites the fuse.
+    /// 
+    /// Explodes all [`Bomb`]s associated to this `Fuse`.
+    /// Each [`Bomb`] receives `value`.
+    /// 
+    /// Alias to [`light`](#method.light)
+    pub fn ignite(self, value: T) -> Fire {
+        self.light(value)
+    }
+
     /// Lights the fuse.
     /// 
     /// Explodes all [`Bomb`]s associated to this `Fuse`.
